require "rest-client"
require "service_shooter/railtie" if defined?(Rails)
require "service_shooter/version"

module ServiceShooter
  class ResponseMapper
    def self.add(data)
      @data = data
    end

    def self.status(code)
      if @data
        @data[code.to_i]
      else
        nil
      end
    end
  end

  class Response
    attr_accessor :code, :message
    def initialize(response)
      response = response.with_indifferent_access
      code = (response[:code] || response[:status]).to_i || 0
      self.code = code
      self.message = response[:message] || ResponseMapper.status(code)
    end
  end

  def self.get(url, params={})
    begin
      flat_params = params.collect{|k,v| "#{k}=#{v}"}.join("&")
      response = JSON.parse(RestClient.get(url+(params.present? ? "?"+flat_params : "")))
    rescue => e
      Rails.logger.fatal e
    end
    response ||= {}
    Response.new(response)
  end

  def self.post(url, params={})
    begin
      response = JSON.parse(RestClient.post(url, params))
    rescue => e
      Rails.logger.fatal e
    end
    response ||= {}
    Response.new(response)
  end

  def self.delete(url, params={})
    begin
      flat_params = params.collect{|k,v| "#{k}=#{v}"}.join("&")
      response = JSON.parse(RestClient.delete(url+(params.present? ? "?"+flat_params : "")))
    rescue => e
      Rails.logger.fatal e
    end
    response ||= {}
    Response.new(response)
  end
end
